@@ -4,8 +4,8 @@ use std::collections::BTreeSet;
 use std::io::BufRead;
 
 // Create clap subcommand arguments
-pub fn make_subcommand<'a>() -> App<'a> {
-    App::new("sort")
+pub fn make_subcommand<'a>() -> Command<'a> {
+    Command::new("sort")
         .about("Sort links and ranges within links")
         .arg(
             Arg::new("infiles")
